@@ -2,13 +2,14 @@ use strict;
 use warnings;
 
 package MooseX::MethodAttributes;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 # ABSTRACT: code attribute introspection
 
 use Moose ();
 use Moose::Exporter;
 use Moose::Util::MetaRole;
+use Moose::Util qw/find_meta does_role/;
 # Ensure trait is registered
 use MooseX::MethodAttributes::Role::Meta::Role ();
 
@@ -17,30 +18,47 @@ Moose::Exporter->setup_import_methods;
 
 sub init_meta {
     my ($class, %options) = @_;
-    my $meta = Moose->init_meta(%options);
-    Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class                      => $options{for_class},
+
+	my $for_class = $options{for_class};
+    my $meta = find_meta($for_class);
+
+    return $meta if $meta
+        && does_role($meta, 'MooseX::MethodAttributes::Role::Meta::Class')
+        && does_role($meta->method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method')
+        && does_role($meta->wrapped_method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped');
+
+    $meta = Moose::Meta::Class->initialize( $for_class )
+        unless $meta;
+
+    $meta = Moose::Util::MetaRole::apply_metaclass_roles(
+        for_class                      => $for_class,
         metaclass_roles                => ['MooseX::MethodAttributes::Role::Meta::Class'],
         method_metaclass_roles         => ['MooseX::MethodAttributes::Role::Meta::Method'],
         wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
     );
-    Moose::Util::MetaRole::apply_base_class_roles(
-        for_class => $options{for_class},
+
+	$for_class = $meta->name;
+	Moose::Util::MetaRole::apply_base_class_roles(
+        for_class => $for_class,
         roles     => ['MooseX::MethodAttributes::Role::AttrContainer'],
     );
+
     return $meta;
 }
 
 1;
 
 __END__
+
+=pod
+
 =head1 NAME
 
 MooseX::MethodAttributes - code attribute introspection
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -58,15 +76,13 @@ version 0.15
 This module allows code attributes of methods to be introspected using Moose
 meta method objects.
 
-=pod
-
 =begin Pod::Coverage
 
 init_meta
 
 =end Pod::Coverage
 
-=cut
+
 
 =head1 AUTHORS
 
@@ -78,5 +94,8 @@ init_meta
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
+
 
